@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20240320';
+our $VERSION = '5.20240920';
 our %utilities;
 
 sub utilities {
@@ -2007,6 +2007,55 @@ my %delta = (
         removed => {
         }
     },
+    5.039010 => {
+        delta_from => 5.039009,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.040000 => {
+        delta_from => 5.039010,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.041000 => {
+        delta_from => 5.040000,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.041001 => {
+        delta_from => 5.041000,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.041002 => {
+        delta_from => 5.041001,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.041003 => {
+        delta_from => 5.041002,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.041004 => {
+        delta_from => 5.041003,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
